Struct Schedule

pub struct Schedule {
    pub method: MethodOrId,
    pub interval: u64,
    pub delay: u64,
}
Schedules are functions that are executed periodically.

This struct is the equivalent of CallAction, just for schedules. Internally all schedules are just actions without any input parameters. They are executed by injecting a CallAction object with the correct method name and an empty params field.

Like CallAction the Schedule struct is always serialized and deserialized as json.

Fields

method: MethodOrId

Method that is called periodically

interval: u64

Schedule interval in milliseconds

delay: u64

Delay in milliseconds for the first schedule execution. Defaults to 0.

Implementations

Source

impl Schedule

pub fn by_method_id(method_id: u32, interval: u64, delay: u64) -> Self

pub fn to_bytes(&self) -> Result<Vec<u8>, Error>

pub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>

pub fn get_action(&self) -> CallAction