Introduction

Struct Introduction 

pub struct Introduction {
    pub id: Id,
    pub participants: Vec<Participant>,
    pub initial_state: Value,
    pub sinks: Vec<Sink>,
    pub subscriptions: Vec<Topic>,
    pub desc: Description,
    pub meta: Metadata,
    pub package: WasmPkg,
}
An introduction of either a contract or agent

There are no two distinct types, since the similarities between contracts and agents are quite big. The main difference is, that agents have no roles attached to them and are not introduced or revoked by a transaction.

Fields

id: Id

Contract- or Agent-ID

participants: Vec<Participant>

List of participants

initial_state: Value

Initial state as JSON value

This will be parsed by the implementors of the contract or agent

sinks: Vec<Sink>

List of available sinks (only relevant for contracts)

subscriptions: Vec<Topic>

List of available subscriptions (only relevant for agents)

desc: Description

High-Level description of the contract or agent

meta: Metadata

metadata of the contract or agent

package: WasmPkg

Definition of the wasm package for this contract or agent

Implementations

Source

impl Introduction

pub fn to_bytes(&self) -> Result<Vec<u8>, Error>

Encode the introduction to json bytes

pub fn from_bytes(bytes: &[u8]) -> Result<Self, Error>

Decode the introduction from json bytes

pub fn pretty_print(&self) -> Result<String, Error>

Pretty-Print the introduction as json