IntroductionDto

Struct IntroductionDto 

pub struct IntroductionDto {
    pub id: Option<Id>,
    pub participants: Vec<Participant>,
    pub initial_state: Value,
    pub sinks: Vec<SinkDto>,
    pub subscriptions: Vec<Topic>,
    pub desc: Description,
    pub package: WasmPkg,
}
Digital-Tranfer-Object (Dto) of an Introduction

When new contracts or agents are created via web-api, things like Metadata do not make sense yet. This DTO omits the metadata and makes the Id optional, so a new Id can be generated for the package.

Fields

id: Option<Id>

Optional Contract- or Agent-ID

If this field is empty, a new ID will be generated for the contract or agent.

participants: Vec<Participant>

List of participants

initial_state: Value

Initial state as JSON value

This will be parsed by the implementors of the contract or agent

sinks: Vec<SinkDto>

List of available sinks

subscriptions: Vec<Topic>

List of available topics

desc: Description

High-Level description of the contract or agent

package: WasmPkg

Definition of the wasm package for this contract or agent