pub fn eid_prefix(bytes: impl AsRef<[u8]>) -> boolExpand description
Check weather or not an array of bytes contains the prefix of an ExternalId.
Useful for filtering in key-value storages, when multiple ID types are used as keys or key-prefixes.
pub fn eid_prefix(bytes: impl AsRef<[u8]>) -> boolCheck weather or not an array of bytes contains the prefix of an ExternalId.
Useful for filtering in key-value storages, when multiple ID types are used as keys or key-prefixes.