Pagination

Struct Pagination 

pub struct Pagination {
    pub page: usize,
    pub per_page: usize,
    pub reverse: bool,
}
Simple struct that is used to add pagination to some endpoint like: /endpoint?page=1&per_page=10

The page numbers start at “1”, so they match what you would display in a frontend.

The default implementation returns you page=1 and per_page=1000.

Fields

page: usizeper_page: usizereverse: bool

Implementations

Source

impl Pagination

pub fn from_query(query: Option<&str>) -> Option<Pagination>

Extracts a pagination from some query string (if any).

The query can contain other elements aswell and there is no necessity for the pieces page and per_page to be two consecutive elements in the query.

As long as there is a page={} element and a per_page={} element, this function will successfully parse and return the Pagination struct.

pub fn to_range(&self) -> Range<usize>

Converts the pagination into a range to iterate over

Note: The index of the range starts at “0” and not at “1”, like the pagination does. No manual conversion needed.