pub struct Schedule {
pub method: MethodOrId,
pub interval: u64,
pub delay: u64,
}Expand description
Schedules are functions that are executed periodically.
This struct is the equivalent of CallAction, just for schedules.
Internally all schedules are just actions without any input parameters.
They are executed by injecting a CallAction object with the correct method name and an empty params field.
Like CallAction the Schedule struct is always serialized and deserialized as json.
Fields
method: MethodOrIdMethod that is called periodically
interval: u64Schedule interval in milliseconds
delay: u64Delay in milliseconds for the first schedule execution. Defaults to 0.
Implementations