pub struct Introduction {
pub id: Id,
pub participants: Vec<Participant>,
pub initial_state: Value,
pub sinks: Vec<Sink>,
pub subscriptions: Vec<Topic>,
pub desc: Description,
pub meta: Metadata,
pub package: WasmPkg,
}Expand description
An introduction of either a contract or agent
There are no two distinct types, since the similarities between contracts and agents are quite big. The main difference is, that agents have no roles attached to them and are not introduced or revoked by a transaction.
Fields
id: IdContract- or Agent-ID
participants: Vec<Participant>List of participants
initial_state: ValueInitial state as JSON value
This will be parsed by the implementors of the contract or agent
sinks: Vec<Sink>List of available sinks (only relevant for contracts)
subscriptions: Vec<Topic>List of available subscriptions (only relevant for agents)
desc: DescriptionHigh-Level description of the contract or agent
meta: Metadatametadata of the contract or agent
package: WasmPkgDefinition of the wasm package for this contract or agent
Implementations
Sourceimpl Introduction
impl Introduction