pub struct Pagination {
pub page: usize,
pub per_page: usize,
pub reverse: bool,
}Expand description
Simple struct that is used to add pagination to some endpoint like: /endpoint?page=1&per_page=10
The page numbers start at “1”, so they match what you would display in a frontend.
The default implementation returns you page=1 and per_page=1000.
Fields
page: usizeper_page: usizereverse: boolImplementations
Sourceimpl Pagination
impl Pagination
Sourcepub fn from_query(query: Option<&str>) -> Option<Pagination>
pub fn from_query(query: Option<&str>) -> Option<Pagination>
Extracts a pagination from some query string (if any).
The query can contain other elements aswell and there is no necessity for the pieces
page and per_page to be two consecutive elements in the query.
As long as there is a page={} element and a per_page={} element,
this function will successfully parse and return the Pagination struct.